@@ -2,7 +2,7 @@
 #
 #	Robot Framework Swarm
 #
-#    Version 0.8.1
+#    Version 0.8.2
 #
 
 
@@ -41,7 +41,7 @@ import inspect
 
 class RFSwarmAgent():
 
-	version="0.8.1"
+	version="0.8.2"
 	config = None
 	isconnected = False
 	isrunning = False
@@ -436,7 +436,10 @@ class RFSwarmAgent():
 			self.findmanager()
 			if self.args.manager:
 				self.debugmsg(7, "self.args.manager: ", self.args.manager)
-				self.swarmmanager = self.args.manager
+				if self.args.manager[-1] != '/':
+					self.swarmmanager = "{}/".format(self.args.manager)
+				else:
+					self.swarmmanager = self.args.manager
 
 		if self.swarmmanager is not None:
 			self.debugmsg(2, "Try connecting to", self.swarmmanager)
@@ -470,6 +473,8 @@ class RFSwarmAgent():
 		if 'swarmmanager' in self.config['Agent']:
 			self.debugmsg(6, "findmanager: Agent:swarmmanager =", self.config['Agent']['swarmmanager'])
 			self.swarmmanager = self.config['Agent']['swarmmanager']
+			if self.swarmmanager[-1] != '/':
+				self.swarmmanager = "{}/".format(self.swarmmanager)
 		else:
 			self.config['Agent']['swarmmanager'] = "http://localhost:8138/"
 			self.saveini()
